@@ -33,7 +33,7 @@ class WebsocketClient:
 
         self.event_handlers: dict[str, Callable[..., Coroutine]] = {}
         self.name = name
-        self.waiting_events: dict[str, dict[int, Future]] = {}
+        self.waiting_events: dict[str, dict[str, Future]] = {}
 
     async def _check(self):
         try:
@@ -60,7 +60,7 @@ class WebsocketClient:
                 uuid: int | None = kwargs.get('__wait_event_uuid')
 
                 if uuid and uuid in self.waiting_events[event]:
-                    self.waiting_events[event][uuid].set_result(True)
+                    self.waiting_events[event][uuid].set_result((args, kwargs))
                     self.waiting_events[event].pop(uuid, None)
 
     async def connect(self):
@@ -79,7 +79,7 @@ class WebsocketClient:
         *args,
         **kwargs
     ):
-        uuid = uuid1().int
+        uuid = uuid1().hex
         kwargs['__wait_event_uuid'] = uuid
 
         if wait_event in self.waiting_events:
@@ -88,7 +88,7 @@ class WebsocketClient:
             self.waiting_events[wait_event] = {uuid: Future()}
 
         await self.emit(event, *args, **kwargs)
-        await self.waiting_events[wait_event][uuid]
+        return await self.waiting_events[wait_event][uuid]
 
     def on(self, event: str):
         """Register event handler."""
